PEP 543: Backport of the Unified TLS API for Python
===================================================

This module contains the draft copy of the proposed ``tls`` module from
`PEP 543`_, the draft specification for the Unified TLS API for Python. This
module is used to centralize development of the API and to flesh out any
difficulties that may be encountered before the module makes it into the
standard library. Once the module is present in the standard library, this
module will become a formal "backport" of the module to support several other
Python versions.

This module is under active development, and is not yet complete. Please
consider very carefully before you rely on it. On the other hand, please by all
means try it out and contribute feedback.

License
-------

This module is made available under the MIT license. See ``LICENSE`` for more
details.


.. _PEP 543: https://www.python.org/dev/peps/pep-0543/
